]> granicus.if.org Git - sudo/commitdiff
filesystem -> file system
authorTodd C. Miller <Todd.Miller@courtesan.com>
Mon, 17 May 2004 22:21:15 +0000 (22:21 +0000)
committerTodd C. Miller <Todd.Miller@courtesan.com>
Mon, 17 May 2004 22:21:15 +0000 (22:21 +0000)
UPGRADE
sudo.c
visudo.c

diff --git a/UPGRADE b/UPGRADE
index 1b37e6337c7a5f08dc91aedf83451e45059cd344..5e13395215cbcf8d4a214a81b5229e595360231b 100644 (file)
--- a/UPGRADE
+++ b/UPGRADE
@@ -65,4 +65,4 @@ o Upgrading from a version prior to 1.5:
     that if have a means of distributing sudo you distribute the
     new binaries first, then the new sudoers file (or you can leave
     sudoers as is and sudo will fix the permissions itself as long
-    as sudoers is on a local filesystem).
+    as sudoers is on a local file system).
diff --git a/sudo.c b/sudo.c
index fde4a8fcdc57859334fc601a107abb9d893d18e4..a0169fbbbf4263508895f5cbf3ab94b196dcec71 100644 (file)
--- a/sudo.c
+++ b/sudo.c
@@ -851,7 +851,7 @@ check_sudoers()
 
     /*
      * Fix the mode and group on sudoers file from old default.
-     * Only works if filesystem is readable/writable by root.
+     * Only works if file system is readable/writable by root.
      */
     if ((rootstat = stat_sudoers(_PATH_SUDOERS, &statbuf)) == 0 &&
        SUDOERS_UID == statbuf.st_uid && SUDOERS_MODE != 0400 &&
index 0c24bfc431116b242508e8bc6fafc79915183948..66cae343ae51c0e61fca8285307b7c3f0d23b7e7 100644 (file)
--- a/visudo.c
+++ b/visudo.c
@@ -443,11 +443,11 @@ main(argc, argv)
     /*
      * Now that we have a sane stmp file (parses ok) it needs to be
      * rename(2)'d to sudoers.  If the rename(2) fails we try using
* mv(1) in case stmp and sudoers are on different filesystems.
      */
     if (rename(stmp, sudoers)) {
        if (errno == EXDEV) {
-           warnx("%s and %s not on the same filesystem, using mv to rename",
+           warnx("%s and %s not on the same file system, using mv to rename",
              stmp, sudoers);
 
            /* Build up argument vector for the command */
@@ -443,11 +443,11 @@ main(argc, argv)
      * Now that we have a sane stmp file (parses ok) it needs to be
      * rename(2)'d to sudoers.  If the rename(2) fails we try using
-     * mv(1) in case stmp and sudoers are on different filesystems.
+     * mv(1) in case stmp and sudoers are on different file systems.
      */
     if (rename(stmp, sudoers)) {